GLMGraph: Fit a graphical model nodewise via generalized linear...

Description Usage Arguments Value Author(s) See Also

View source: R/Functions_GE.r

Description

Fit a graphical model nodewise via generalized linear regression

Usage

1
GLMGraph(Y.r, Y.p, Z = NULL, nlambda = 50, family = "gaussian", intercept = T, lambda.min.ratio = 0.01, weight.zero = 1, hetero.penalty = F)

Arguments

Y.r

response of nodewise regressions, an nxp matrix

Y.p

predictors of nodewise regressions, a matrix of the same dimension as Y.r

Z

extra predictor matrix for all nodewise regressions

nlambda

number of lambda values on grid (default 50)

family

"gaussian" or "poisson"

intercept

whether to include an intercept term in each nodewise regressions

lambda.min.ratio

ratio between the minimum and the maximum of the lambda sequence

weight.zero

Weight of zero-response samples in nodewise regressions

Value

lambda

the lambda sequence used in nodewise regressions

graphs

a sequence of estimated graphs

coef.opt

a pxp matrix of EBIC-selected coefficient estimates of all nodewise regressions

coef.aic

a pxp matrix of AIC-selected coefficient estimates of all nodewise regressions

Author(s)

Jianyu Liu

See Also

hugeGraph, MPoisGraph, MHurdGraph


hwang655/HUG documentation built on Jan. 31, 2021, 2:54 a.m.