GraphAcc: Evaluate the accuracy of graph estimation

Description Usage Arguments Details Value Author(s)

View source: R/Functions_Graph.r

Description

Evaluate the accuracy of a list of graph estimates.

Usage

1
GraphAcc(graphs, graph.t)

Arguments

graphs

a list of graph estimates in the form of adjacency matrices

graph.t

the benchmark graph in the form of adjacency matrix

Details

No symmetrization will be performed on the graph estimates graphs; graph.t will be symmetrized.

Value

A data.frame of accuracy evaluation results, including true positives (TP), false positives (FP), false negatives (FN), number of nonzero values in each estimated adjacency matrix (DF), number of nonzero values in the benchmark adjacency matrix (DF_T). Each row corresponds to an estimated graph in graphs.

Author(s)

Jianyu Liu


hwang655/HUG documentation built on Jan. 31, 2021, 2:54 a.m.