HUG-package: Dependent Graphical Model Estimation

Description Details Author(s) References

Description

This package implements a least square approximation (LSA) algorithm to estimate dependent Poisson and Hurdle graphical models.

Details

The DESCRIPTION file: This package was not yet installed at build time.
Index: This package was not yet installed at build time.

Author(s)

Jianyu Liu

Maintainer: Jianyu Liu <liu.shufe@gmail.com>

References

Liu, Jianyu, Haodong Wang, Wei Sun, Yufeng Liu. "Graphical Model Estimation for Single Cell RNA-seq Data." (2019+)


hwang655/HUG documentation built on Jan. 31, 2021, 2:54 a.m.