MHurdGraph: Fit a dependent Hurdle graphical model

Description Usage Arguments Value Author(s) See Also

View source: R/Functions_GE.r

Description

Fit a dependent Hurdle graphical model via nodewise random effect Hurdle regression.

Usage

1
MHurdGraph(Y.r, Y.p, B.ini, Omega = NULL, coef.hurd = NULL, nlambda = 50, lambda.max = 10, lambda.min.ratio = 0.01)

Arguments

Y.r

response of nodewise regressions, an nxp matrix

Y.p

predictors of nodewise regressions, a matrix of the same dimension as Y.r

B.ini

a reasonable initial coefficient matrix for the nodewise Hurdle regression

Omega

(optional) precision matrix of the sample dependence model

coef.hurd

(optional) coefficients of the Hurdle models, i.e. gamma0, gamma1

nlambda

number of lambda values on grid (default 50)

lambda.max

maximum of the lambda sequence

lambda.min.ratio

ratio between the minimum and the maximum of the lambda sequence

Value

lambda

the lambda sequence used in nodewise regressions

graphs

a sequence of estimated graphs

coef.opt

a pxp matrix of EBIC-selected coefficient estimates of all nodewise regressions

coef.aic

a pxp matrix of AIC-selected coefficient estimates of all nodewise regressions

coef.hurd

coefficient estimation for the hurdle model

time

time spent on each regression in second

Author(s)

Jianyu Liu

See Also

GLMGraph, hugeGraph, MPoisGraph


hwang655/HUG documentation built on Jan. 31, 2021, 2:54 a.m.