Description Usage Arguments Value Author(s) See Also
Fit a dependent Poisson graphical model via nodewise random effect Poisson regression.
1 | MPoisGraph(Y.r, Y.p, B.ini, Omega = NULL, nlambda = 50, lambda.max = 10, lambda.min.ratio = 0.01)
|
Y.r |
response of nodewise regressions, an nxp matrix |
Y.p |
predictors of nodewise regressions, a matrix of the same dimension as |
B.ini |
a reasonable initial coefficient matrix for the nodewise Hurdle regression |
Omega |
(optional) precision matrix of the sample dependence model |
nlambda |
number of lambda values on grid (default 50) |
lambda.max |
maximum of the lambda sequence |
lambda.min.ratio |
ratio between the minimum and the maximum of the lambda sequence |
lambda |
the lambda sequence used in nodewise regressions |
graphs |
a sequence of estimated graphs |
coef.opt |
a pxp matrix of EBIC-selected coefficient estimates of all nodewise regressions |
coef.aic |
a pxp matrix of AIC-selected coefficient estimates of all nodewise regressions |
time |
time spent on each regression in second |
Jianyu Liu
GLMGraph, hugeGraph, MHurdGraph
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.