PlotGraphs: Plot multiple undirected graphs in one plot

Description Usage Arguments Value Author(s)

View source: R/Functions_Display.r

Description

Plot multiple undirected graphs in one plot and display overlapping

Usage

1
PlotGraphs(icovs, graph4layout = NULL, cmpl.layout = NULL, v.keep = NULL, v.name = NULL, v.label = NULL, rmd = TRUE, name.icovs = NULL, legend = TRUE, layout.only = FALSE, conflict.disp = FALSE, ...)

Arguments

icovs

a list of graphs in the form of nxn adjacency matrices

graph4layout

(optional) a graph based on which the node positions are determined

cmpl.layout

(optional) an nx2 matrix containing the coordinates of all n nodes

v.keep

(optional) an index array of nodes to be displayed. By default, only nodes with >=1 connection are kept

v.name

(optional) a character array of node names

v.label

(optional) a character array of node symbols

rmd

open a new plotting window if FALSE. TRUE by default

name.icovs

(optional) a character array of graph names

legend

whether to plot a legend

layout.only

do not display the graphs if TRUE. FALSE by default

conflict.disp

display edges of opposite signs if TRUE. FALSE by default

Value

An nx2 matrix containing the coordinates of all n nodes

Author(s)

Jianyu Liu


hwang655/HUG documentation built on Jan. 31, 2021, 2:54 a.m.