rMVH: Generate Hurdle random vectors with sample dependence

Description Usage Arguments Value Author(s) See Also Examples

View source: R/Functions_Simulate.r

Description

Generate Hurdle random vectors with sample dependence

Usage

1
rMVH(coef.hurd, mu, size, g.type, factor.re = 1)

Arguments

coef.hurd

gamma_0 and gamma_1 of the Hurdle model

mu

a p-dimensional mean vector of the underlying Gaussian random vector

size

sample size

g.type

type of the underlying graph, one of "banded", "hub", and "random"

factor.re

inverse scale of the sample dependence

Value

Y

an nxp sample matrix, where each row for a sample and each column for a variable

X

an nxp matrix of the underlying Gaussian data with sample dependence

Z

a list of two Gaussian components

graph

the underlying true graph of the random variables

Author(s)

Jianyu Liu

See Also

rMVP

Examples

1
Y = rMVH(c(0, 0.5), mu=rep(2, 100), size=80, g.type='hub', factor.re=.5)

hwang655/HUG documentation built on Jan. 31, 2021, 2:54 a.m.