Description Usage Arguments Value Author(s) See Also
Fit a graphical model nodewise via generalized linear regression
1 |
Y.r |
response of nodewise regressions, an nxp matrix |
Y.p |
predictors of nodewise regressions, a matrix of the same dimension as |
Z |
extra predictor matrix for all nodewise regressions |
nlambda |
number of lambda values on grid (default 50) |
family |
"gaussian" or "poisson" |
intercept |
whether to include an intercept term in each nodewise regressions |
lambda.min.ratio |
ratio between the minimum and the maximum of the lambda sequence |
weight.zero |
Weight of zero-response samples in nodewise regressions |
lambda |
the lambda sequence used in nodewise regressions |
graphs |
a sequence of estimated graphs |
coef.opt |
a pxp matrix of EBIC-selected coefficient estimates of all nodewise regressions |
coef.aic |
a pxp matrix of AIC-selected coefficient estimates of all nodewise regressions |
Jianyu Liu
hugeGraph, MPoisGraph, MHurdGraph
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.