Description Usage Arguments Details Value Author(s)
View source: R/Functions_Graph.r
Evaluate the accuracy of a list of graph estimates.
1 | GraphAcc(graphs, graph.t)
|
graphs |
a list of graph estimates in the form of adjacency matrices |
graph.t |
the benchmark graph in the form of adjacency matrix |
No symmetrization will be performed on the graph estimates graphs; graph.t will be symmetrized.
A data.frame of accuracy evaluation results, including true positives (TP), false positives (FP), false negatives (FN), number of nonzero values in each estimated adjacency matrix (DF), number of nonzero values in the benchmark adjacency matrix (DF_T). Each row corresponds to an estimated graph in graphs.
Jianyu Liu
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.