Description Details Author(s) References
This package implements a least square approximation (LSA) algorithm to estimate dependent Poisson and Hurdle graphical models.
The DESCRIPTION file:
This package was not yet installed at build time.
Index: This package was not yet installed at build time.
Jianyu Liu
Maintainer: Jianyu Liu <liu.shufe@gmail.com>
Liu, Jianyu, Haodong Wang, Wei Sun, Yufeng Liu. "Graphical Model Estimation for Single Cell RNA-seq Data." (2019+)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.