Description Usage Arguments Value Author(s)
View source: R/Functions_Display.r
Plot multiple undirected graphs in one plot and display overlapping
1 |
icovs |
a list of graphs in the form of nxn adjacency matrices |
graph4layout |
(optional) a graph based on which the node positions are determined |
cmpl.layout |
(optional) an nx2 matrix containing the coordinates of all n nodes |
v.keep |
(optional) an index array of nodes to be displayed. By default, only nodes with >=1 connection are kept |
v.name |
(optional) a character array of node names |
v.label |
(optional) a character array of node symbols |
rmd |
open a new plotting window if |
name.icovs |
(optional) a character array of graph names |
legend |
whether to plot a legend |
layout.only |
do not display the graphs if |
conflict.disp |
display edges of opposite signs if |
An nx2 matrix containing the coordinates of all n nodes
Jianyu Liu
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.