Description Usage Arguments Value Author(s) See Also Examples
View source: R/Functions_Simulate.r
Generate Hurdle random vectors with sample dependence
1 | rMVH(coef.hurd, mu, size, g.type, factor.re = 1)
|
coef.hurd |
gamma_0 and gamma_1 of the Hurdle model |
mu |
a p-dimensional mean vector of the underlying Gaussian random vector |
size |
sample size |
g.type |
type of the underlying graph, one of "banded", "hub", and "random" |
factor.re |
inverse scale of the sample dependence |
Y |
an nxp sample matrix, where each row for a sample and each column for a variable |
X |
an nxp matrix of the underlying Gaussian data with sample dependence |
Z |
a list of two Gaussian components |
graph |
the underlying true graph of the random variables |
Jianyu Liu
rMVP
1 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.